New building blocks
===================

New BuildingBlock classes to replace :class:`stk.BuildingBlock`. They may
inherit or contain the ``stk`` class, depending on design considerations.

.. toctree::
  :maxdepth: 1

  PanelBuildingBlock <_autosummary/bbprep.PanelBuildingBlock>
